==> vue-exception-2.8.0.tgz: package/lib/mobile.js <==
import { renderless, api } from "@xmweb-ui/vue-renderless/exception/vue";
import { defineComponent, $prefix, setup as _setup } from "@xmweb-ui/vue-common";
import Button from "@xmweb-ui/vue-button";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "Exception",
  components: {
    XmButton: Button
  },
  props: {
    type: {
      type: String,
      default: "nodata"
    },
    message: String,
    subMessage: String,
    exceptionClass: String,
    buttonText: String,
    imageUrl: String
  },
  setup: function setup(props, context) {
    return _setup({
      props,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "xm-mobile-exception",
    class: _vm.exceptionClass
  }, [_c("div", {
    staticClass: "xm-mobile-exception__content"
  }, [_vm.imageUrl ? _c("img", {
    staticClass: "xm-mobile-exception__image",
    attrs: {
      "src": _vm.imageUrl
    }
  }) : _c("div", {
    staticClass: "xm-mobile-exception__content-view",
    class: ["xm-mobile-exception__content-" + _vm.type]
  }), _vm._t("content", function() {
    return [_c("div", {
      staticClass: "xm-mobile-exception__content-message"
    }, [_c("div", {
      staticClass: "main-message"
    }, [_vm._v(" " + _vm._s(_vm.state.message) + " ")]), _vm.subMessage ? _c("div", {
      staticClass: "sub-message"
    }, [_vm._v(" " + _vm._s(_vm.subMessage) + " ")]) : _vm._e(), _vm.type === "nodata" ? _vm._t("default", function() {
      return [_c("xm-button", {
        attrs: {
          "type": "primary",
          "size": "medium",
          "round": ""
        },
        on: {
          "click": _vm.create
        }
      }, [_vm._v(" " + _vm._s(_vm.buttonText ? _vm.buttonText : _vm.t("ui.exception.create")) + " ")])];
    }) : _vm._e()], 2)];
  })], 2), _c("div", {
    staticClass: "xm-mobile-exception__footer"
  }, [_vm._t("footer")], 2)]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobile = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  mobile as default
};

==> vue-exception-2.21.0.tgz: package/lib/mobile.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/exception/vue';
import { defineComponent, $prefix, setup } from '@opentinyvue/vue-common';
import Button from '@opentinyvue/vue-button';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "Exception",
  components: {
    TinyButton: Button
  },
  props: {
    type: {
      type: String,
      default: "nodata"
    },
    message: String,
    subMessage: String,
    exceptionClass: String,
    buttonText: String,
    imageUrl: String
  },
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "tiny-mobile-exception",
    class: _vm.exceptionClass
  }, [_c("div", {
    staticClass: "tiny-mobile-exception__content"
  }, [_vm.imageUrl ? _c("img", {
    staticClass: "tiny-mobile-exception__image",
    attrs: {
      "src": _vm.imageUrl
    }
  }) : _c("div", {
    staticClass: "tiny-mobile-exception__content-view",
    class: ["tiny-mobile-exception__content-" + _vm.type]
  }), _vm._t("content", function() {
    return [_c("div", {
      staticClass: "tiny-mobile-exception__content-message"
    }, [_c("div", {
      staticClass: "main-message"
    }, [_vm._v(" " + _vm._s(_vm.state.message) + " ")]), _vm.subMessage ? _c("div", {
      staticClass: "sub-message"
    }, [_vm._v(" " + _vm._s(_vm.subMessage) + " ")]) : _vm._e(), _vm.type === "nodata" ? _vm._t("default", function() {
      return [_c("tiny-button", {
        attrs: {
          "type": "primary",
          "size": "medium",
          "round": ""
        },
        on: {
          "click": _vm.create
        }
      }, [_vm._v(" " + _vm._s(_vm.buttonText ? _vm.buttonText : _vm.t("ui.exception.create")) + " ")])];
    }) : _vm._e()], 2)];
  })], 2), _c("div", {
    staticClass: "tiny-mobile-exception__footer"
  }, [_vm._t("footer")], 2)]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobile = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobile as default };
